pub enum ConformanceClass {
A,
B,
C,
}Expand description
Interoperability conformance class (gbp-interop-profile 2).
Variants
A
Class A: GBP + GSP (mandatory minimum).
B
Class B: Class A + GTP (text messaging).
C
Class C: Class B + GAP (audio).
Implementations
Sourceimpl ConformanceClass
impl ConformanceClass
Sourcepub fn tokens(self) -> &'static [&'static str]
pub fn tokens(self) -> &'static [&'static str]
Returns all capability tokens that must be advertised for this class (including tokens for lower classes — each class implies the ones below).
Sourcepub fn from_tokens<'a>(
tokens: impl IntoIterator<Item = &'a str>,
) -> Option<Self>
pub fn from_tokens<'a>( tokens: impl IntoIterator<Item = &'a str>, ) -> Option<Self>
Infers the highest conformance class from a set of capability tokens.
Returns None if not even Class A is present.